@@ -148,8 +148,9 @@ add_button_cb(
     {
       l_len= strlen(l_value_parent);
       l_len+= strlen(l_value_child);
-      l_value= g_malloc0(2+l_len);
-      sprintf(l_value, "%s.%s", l_value_parent, l_value_child);
+      l_len+= 2;
+      l_value= g_malloc0(l_len);
+      snprintf(l_value, l_len, "%s.%s", l_value_parent, l_value_child);
     }
 
     l_rc= tree_attr_has_entry((*l_export).m_tree_attr, l_value);
@@ -234,8 +235,9 @@ add_all_button_cb(
       {
         l_len= strlen(l_value_parent);
         l_len+= strlen(l_value_child);
-        l_value= g_malloc0(2+l_len);
-        sprintf(l_value, "%s.%s", l_value_parent, l_value_child);
+        l_len+=2;
+        l_value= g_malloc0(l_len);
+        snprintf(l_value, l_len, "%s.%s", l_value_parent, l_value_child);
       }
 
       l_rc= tree_attr_has_entry((*l_export).m_tree_attr, l_value);
@@ -456,17 +458,6 @@ export_assign(
   return;
 }
 
-extern void
-export_assign_filename(
-  struct exports*const                  io_export,
-  char const*                           i_reportfile)
-{
-
-  export_config_assign_filename(&(*io_export).m_config, i_reportfile);
-
-  return;
-}
-
 extern void
 export_discharge(
   struct exports *const                 io_export)
@@ -484,50 +475,6 @@ export_discharge(
   return;
 }
 
-static void
-export_read_array(
-  struct exports *const                 io_export,
-  struct bson_node const*               i_element)
-{
-  struct bson_node const*               l_element;
-  GtkTreeIter                           l_iter;
-  GtkListStore*                         l_store;
-
-  l_element= i_element;
-  memset(&l_iter, 0, sizeof(l_iter));
-  l_store= GTK_LIST_STORE(gtk_tree_view_get_model((*io_export).m_tree_attr));
-
-  do
-  {
-
-    if (0 == l_element)
-    {
-      break;
-    }
-
-    if (bson_type_end == (*l_element).m_type)
-    {
-      break;
-    }
-
-    if (bson_type_string == (*l_element).m_type)
-    {
-      gtk_list_store_append(l_store, &l_iter);
-      gtk_list_store_set(
-        l_store, 
-        &l_iter,
-        0, 
-        (*l_element).m_object.m_string.m_text, 
-        -1);
-    }
-
-    l_element= (*l_element).m_next;
-
-  }while(1);
-
-  return;
-}
-
 extern GtkWidget*
 export_gui_new(
   struct exports *const                 io_export)
@@ -587,75 +534,26 @@ export_gui_new(
   return GTK_WIDGET((*io_export).m_grid);
 }
 
-extern int
-export_read(
-  GError**                              o_error,
+extern void
+export_load_attr_from_array(
   struct exports *const                 io_export,
-  struct bson_node const*const          i_element)
+  char *const*                          i_fields,
+  unsigned const                        i_slots)
 {
-  struct bson_node const*               l_bson;
-  struct bson_node const*               l_bson_array;
-  int                                   l_exit;
-  int                                   l_rc;
+  unsigned                              l_slot;
+  GtkTreeIter                           l_iter;
+  GtkListStore*                         l_store;
 
-  do
+  memset(&l_iter, 0, sizeof(l_iter));
+  l_store= GTK_LIST_STORE(gtk_tree_view_get_model((*io_export).m_tree_attr));
+
+  for(l_slot= 0; i_slots > l_slot; l_slot++)
   {
+    gtk_list_store_append(l_store, &l_iter);
+    gtk_list_store_set(l_store, &l_iter, 0, i_fields[l_slot], -1);
+  }
 
-    l_exit= export_config_read(o_error, &(*io_export).m_config);
-
-    if (l_exit)
-    {
-      break;
-    }
-
-    l_bson= i_element;
-
-    do
-    {
-
-      if (0 == l_bson)
-      {
-        break;
-      }
-
-      do
-      {
-
-        if (bson_type_array != (*l_bson).m_type)
-        {
-          break;
-        }
-
-        l_bson_array= (*l_bson).m_object.m_document.m_head;
-
-        if (0 == l_bson_array)
-        {
-          break;
-        }
-
-        l_rc= strcmp("attribute", (*l_bson).m_ename);
-
-        if (l_rc)
-        {
-          break;
-        }
-
-        export_read_array(io_export, l_bson_array);
-
-      }while(0);
-
-      if (l_exit)
-      {
-        break;
-      }
-
-      l_bson= (*l_bson).m_next;
-
-    }while(1);
-
-  }while(0);
-
-  return 0;
+  return;
 }
 
 extern void
@@ -724,10 +622,6 @@ export_write(
 {
   gboolean                              l_bool;
   int                                   l_exit;
-  int32_t                               l_int32;
-  char                                  l_octet;
-  int32_t                               l_offset;
-  int32_t                               l_size;
   GtkTreeIter                           l_iter;
   gchar*                                l_value;
   GtkTreeModel*                         l_model;
@@ -737,21 +631,14 @@ export_write(
   do
   {
 
-    l_exit= export_config_write(o_error, &(*i_export).m_config);
+    l_exit= export_config_write(o_error, io_fp, &(*i_export).m_config);
 
     if (l_exit)
     {
       break;
     }
 
-    l_octet= bson_type_array;
-    fwrite(&l_octet, 1, 1, io_fp); 
-    fprintf(io_fp, "%s%c", "attribute", 0);
-
-    /* document */
-    l_offset= ftell(io_fp);
-    l_int32= 0;
-    fwrite(&l_int32, sizeof(int32_t), 1, io_fp); 
+    fprintf(io_fp, "\t<tags>\n");
 
     l_model= gtk_tree_view_get_model((*i_export).m_tree_attr);
     l_bool= gtk_tree_model_get_iter_first(l_model, &l_iter);
@@ -765,30 +652,13 @@ export_write(
       }
 
       gtk_tree_model_get(l_model, &l_iter, 0, &l_value, -1);
-
-      l_octet= bson_type_string;
-      fwrite(&l_octet, 1, 1, io_fp); 
-      fprintf(io_fp, "text%c",0);
-      l_size= 1+strlen(l_value);
-      fwrite(&l_size, sizeof(int32_t), 1, io_fp); 
-      fwrite(l_value, 1, l_size, io_fp);
-      g_free(l_value);
+      fprintf(io_fp, "\t\t<tag>%s</tag>\n", l_value);
 
       l_bool= gtk_tree_model_iter_next(l_model, &l_iter);
 
     }while(1);
 
-    /* end of document */
-    l_octet= 0;
-    fwrite(&l_octet, 1, 1, io_fp); 
-
-    /* document */
-    l_int32= ftell(io_fp);
-    l_size= (l_int32 - l_offset);
-    fseek(io_fp, l_offset, SEEK_SET);
-    fwrite(&l_size, sizeof(l_size), 1, io_fp); 
-
-    fseek(io_fp, 0, SEEK_END);
+    fprintf(io_fp, "\t</tags>\n");
 
   }while(0);
 
