@@ -103,7 +103,7 @@ item_fnumber_color_button_cb(
 
     l_fnumber= (struct fnumber_dialog*)i_data;
 
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", mainw());
+    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
 
     l_text= gtk_entry_get_text((*l_fnumber).m_color_entry);
     gdk_rgba_parse(&l_color, l_text);
@@ -153,7 +153,8 @@ item_fnumber_border_color_button_cb(
 
     l_fnumber= (struct fnumber_dialog*)i_data;
 
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", mainw());
+    l_dialog= gtk_color_chooser_dialog_new("Fill Color", get_main_window());
+    gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(l_dialog), 1);
 
     l_text= gtk_entry_get_text((*l_fnumber).m_color_entry);
     gdk_rgba_parse(&l_color, l_text);
@@ -203,7 +204,7 @@ item_fnumber_fill_color_button_cb(
 
     l_fnumber= (struct fnumber_dialog*)i_data;
 
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", mainw());
+    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
 
     l_text= gtk_entry_get_text((*l_fnumber).m_color_entry);
     gdk_rgba_parse(&l_color, l_text);
@@ -255,7 +256,7 @@ item_fnumber_font_button_cb(
 
     l_text= gtk_entry_get_text(GTK_ENTRY((*l_fnumber).m_font_entry));
 
-    l_dialog= gtk_font_chooser_dialog_new("Font", mainw());
+    l_dialog= gtk_font_chooser_dialog_new("Font", get_main_window());
 
     gtk_font_chooser_set_font(GTK_FONT_CHOOSER(l_dialog), l_text);
 
@@ -403,26 +404,26 @@ item_fnumber_set_values(
 
   gtk_toggle_button_set_active(
     GTK_TOGGLE_BUTTON((*i_fnumberd).m_border_checkbutton),
-    (*i_fnumber).m_border);
+    (*i_fnumber).m_border.m_active);
 
   gtk_combo_box_set_active(
       GTK_COMBO_BOX((*i_fnumberd).m_border_style_comboboxtext), 
-      (*i_fnumber).m_border_style);
+      (*i_fnumber).m_border.m_style);
 
   gtk_spin_button_set_value(
     GTK_SPIN_BUTTON((*i_fnumberd).m_border_thickness_spinbutton),
-    (*i_fnumber).m_border_thickness);
+    (*i_fnumber).m_border.m_thickness);
 
-  l_color= gdk_rgba_to_string(&(*i_fnumber).m_border_color);
+  l_color= gdk_rgba_to_string(&(*i_fnumber).m_border.m_color);
   gtk_entry_set_text((*i_fnumberd).m_border_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
   gtk_toggle_button_set_active(
     GTK_TOGGLE_BUTTON((*i_fnumberd).m_fill_color_checkbutton),
-    (*i_fnumber).m_fill);
+    (*i_fnumber).m_fill.m_active);
 
-  l_color= gdk_rgba_to_string(&(*i_fnumber).m_fill_color);
+  l_color= gdk_rgba_to_string(&(*i_fnumber).m_fill.m_color);
   gtk_entry_set_text((*i_fnumberd).m_fill_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
@@ -465,7 +466,7 @@ item_fnumber_copy_values(
   }
   (*io_fnumber).m_font= pango_font_description_from_string(l_text);
 
-  (*io_fnumber).m_border=
+  (*io_fnumber).m_border.m_active=
     gtk_toggle_button_get_active(
       GTK_TOGGLE_BUTTON((*i_fnumberd).m_border_checkbutton));
 
@@ -474,25 +475,25 @@ item_fnumber_copy_values(
 
   if ((0 <= l_rc) && (LINE_STYLE_SLOTS > l_rc))
   {
-    (*io_fnumber).m_border_style= (enum line_style_type)l_rc;
+    (*io_fnumber).m_border.m_style= (enum line_style_type)l_rc;
   }
   else
   {
-    (*io_fnumber).m_border_style= line_style_solid;
+    (*io_fnumber).m_border.m_style= line_style_solid;
   }
 
-  (*io_fnumber).m_border_thickness= gtk_spin_button_get_value_as_int(
+  (*io_fnumber).m_border.m_thickness= gtk_spin_button_get_value(
     GTK_SPIN_BUTTON((*i_fnumberd).m_border_thickness_spinbutton));
 
   l_text= gtk_entry_get_text(GTK_ENTRY((*i_fnumberd).m_border_color_entry));
-  gdk_rgba_parse(&(*io_fnumber).m_border_color, l_text);
+  gdk_rgba_parse(&(*io_fnumber).m_border.m_color, l_text);
 
-  (*io_fnumber).m_fill=
+  (*io_fnumber).m_fill.m_active=
     gtk_toggle_button_get_active(
       GTK_TOGGLE_BUTTON((*i_fnumberd).m_fill_color_checkbutton));
 
   l_text= gtk_entry_get_text(GTK_ENTRY((*i_fnumberd).m_fill_color_entry));
-  gdk_rgba_parse(&(*io_fnumber).m_fill_color, l_text);
+  gdk_rgba_parse(&(*io_fnumber).m_fill.m_color, l_text);
 
   l_rc = gtk_combo_box_get_active(
     GTK_COMBO_BOX((*i_fnumberd).m_type_comboboxtext));
@@ -584,7 +585,7 @@ item_fnumber_property(
 
     l_dialog= GTK_DIALOG(gtk_dialog_new_with_buttons(
       "Field Edit",
-      mainw(),
+      get_main_window(),
       GTK_DIALOG_MODAL,
       "Ok",
       GTK_RESPONSE_OK,
