@@ -104,7 +104,7 @@ item_fsum_color_button_cb(
 
     l_sum= (struct sum_dialog*)i_data;
 
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", mainw());
+    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
 
     l_text= gtk_entry_get_text((*l_sum).m_color_entry);
     gdk_rgba_parse(&l_color, l_text);
@@ -154,7 +154,7 @@ item_fsum_border_color_button_cb(
 
     l_sum= (struct sum_dialog*)i_data;
 
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", mainw());
+    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
 
     l_text= gtk_entry_get_text((*l_sum).m_border_color_entry);
     gdk_rgba_parse(&l_color, l_text);
@@ -204,7 +204,8 @@ item_fsum_fill_color_button_cb(
 
     l_sum= (struct sum_dialog*)i_data;
 
-    l_dialog= gtk_color_chooser_dialog_new("Fill Color", mainw());
+    l_dialog= gtk_color_chooser_dialog_new("Fill Color", get_main_window());
+    gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(l_dialog), 1);
 
     l_text= gtk_entry_get_text((*l_sum).m_fill_color_entry);
     gdk_rgba_parse(&l_color, l_text);
@@ -256,7 +257,7 @@ item_fsum_font_button_cb(
 
     l_text= gtk_entry_get_text(GTK_ENTRY((*l_sum).m_font_entry));
 
-    l_dialog= gtk_font_chooser_dialog_new("Font", mainw());
+    l_dialog= gtk_font_chooser_dialog_new("Font", get_main_window());
 
     gtk_font_chooser_set_font(GTK_FONT_CHOOSER(l_dialog), l_text);
 
@@ -407,26 +408,26 @@ item_fsum_set_values(
 
   gtk_toggle_button_set_active(
     GTK_TOGGLE_BUTTON((*i_sumd).m_border_checkbutton),
-    (*i_sum).m_border);
+    (*i_sum).m_border.m_active);
 
   gtk_combo_box_set_active(
       GTK_COMBO_BOX((*i_sumd).m_border_style_comboboxtext), 
-      (*i_sum).m_border_style);
+      (*i_sum).m_border.m_style);
 
   gtk_spin_button_set_value(
     GTK_SPIN_BUTTON((*i_sumd).m_border_thickness_spinbutton),
-    (*i_sum).m_border_thickness);
+    (*i_sum).m_border.m_thickness);
 
-  l_color= gdk_rgba_to_string(&(*i_sum).m_border_color);
+  l_color= gdk_rgba_to_string(&(*i_sum).m_border.m_color);
   gtk_entry_set_text((*i_sumd).m_border_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
   gtk_toggle_button_set_active(
     GTK_TOGGLE_BUTTON((*i_sumd).m_fill_color_checkbutton),
-    (*i_sum).m_fill);
+    (*i_sum).m_fill.m_active);
 
-  l_color= gdk_rgba_to_string(&(*i_sum).m_fill_color);
+  l_color= gdk_rgba_to_string(&(*i_sum).m_fill.m_color);
   gtk_entry_set_text((*i_sumd).m_fill_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
@@ -470,7 +471,7 @@ item_fsum_copy_values(
   }
   (*io_sum).m_font= pango_font_description_from_string(l_text);
 
-  (*io_sum).m_border=
+  (*io_sum).m_border.m_active=
     gtk_toggle_button_get_active(
       GTK_TOGGLE_BUTTON((*i_sumd).m_border_checkbutton));
 
@@ -479,25 +480,25 @@ item_fsum_copy_values(
 
   if ((0 <= l_rc) && (LINE_STYLE_SLOTS > l_rc))
   {
-    (*io_sum).m_border_style= (enum line_style_type)l_rc;
+    (*io_sum).m_border.m_style= (enum line_style_type)l_rc;
   }
   else
   {
-    (*io_sum).m_border_style= line_style_solid;
+    (*io_sum).m_border.m_style= line_style_solid;
   }
 
-  (*io_sum).m_border_thickness= gtk_spin_button_get_value_as_int(
+  (*io_sum).m_border.m_thickness= gtk_spin_button_get_value(
     GTK_SPIN_BUTTON((*i_sumd).m_border_thickness_spinbutton));
 
   l_text= gtk_entry_get_text(GTK_ENTRY((*i_sumd).m_border_color_entry));
-  gdk_rgba_parse(&(*io_sum).m_border_color, l_text);
+  gdk_rgba_parse(&(*io_sum).m_border.m_color, l_text);
 
-  (*io_sum).m_fill=
+  (*io_sum).m_fill.m_active=
     gtk_toggle_button_get_active(
       GTK_TOGGLE_BUTTON((*i_sumd).m_fill_color_checkbutton));
 
   l_text= gtk_entry_get_text(GTK_ENTRY((*i_sumd).m_fill_color_entry));
-  gdk_rgba_parse(&(*io_sum).m_fill_color, l_text);
+  gdk_rgba_parse(&(*io_sum).m_fill.m_color, l_text);
 
   l_rc = gtk_combo_box_get_active(
     GTK_COMBO_BOX((*i_sumd).m_type_comboboxtext));
@@ -593,7 +594,7 @@ item_fsum_property(
 
     l_dialog= GTK_DIALOG(gtk_dialog_new_with_buttons(
       "Sum Edit",
-      mainw(),
+      get_main_window(),
       GTK_DIALOG_MODAL,
       "Ok",
       GTK_RESPONSE_OK,
