@@ -791,68 +791,6 @@ iwr_page_new()
   return GTK_WIDGET(l_gobject);
 }
 
-extern int
-iwr_page_read(
-  GError**                              o_error,
-  IwrPage*const                         io_page,
-  struct bson_node const*const          i_element)
-{
-  struct bson_node const*               l_element;
-  int                                   l_exit;
-  int                                   l_found;
-  IwrPagePrivate*                       l_priv; 
-  enum element_tag_type                 l_type;
-
-  l_element= i_element;
-  l_exit= 0;
-  l_priv= (*io_page).m_priv;
-
-  do
-  {
-
-    if (0 == l_element)
-    {
-      break;
-    }
-
-    do
-    {
-
-      if (bson_type_array == (*l_element).m_type)
-      {
-        l_exit= item_node_read(o_error, &(*l_priv).m_item, l_element);
-        break;
-      }
-
-      item_common_lookup(&l_found, &l_type, (*l_element).m_ename);
-
-      if (0 == l_found)
-      {
-        break;
-      }
-
-      switch(l_type)
-      {
-        case element_tag_type:
-          if (bson_type_int32 == (*l_element).m_type)
-          {
-            (*l_priv).m_type= (enum iwr_page_section_type)
-              (*l_element).m_object.m_int32;
-          }
-          break;
-        default:
-          break;
-      }
-
-    }while(0);
-    
-    l_element= (*l_element).m_next;
-
-  }while(1);
-
-  return l_exit;
-}
-
 static void
 iwr_page_draw_margin_cover(
   cairo_t*                              io_cr,
@@ -1278,16 +1216,3 @@ iwr_page_set_section_type(
 
   return;
 }
-
-extern int
-iwr_page_write(
-  GError**                              o_error,
-  FILE*const                            io_fp,
-  IwrPage const*const                   i_page)
-{
-  int                                   l_exit;
-
-  l_exit= item_node_write(o_error, io_fp, &(*i_page).m_priv->m_item);
-
-  return l_exit;
-}
