@@ -53,7 +53,7 @@ layout_add_default_sections(
   /*double                                l_paper_height;*/
   IwrPage*                              l_page;
 
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
+  l_paper= (*io_layout).m_paper;
   l_row= 0;
   /*l_paper_height= l_paper.m_height;*/
 
@@ -63,7 +63,7 @@ layout_add_default_sections(
   gtk_widget_set_sensitive(l_widget, 0);
   l_page= IWR_PAGE(iwr_page_new());
   (*io_layout).m_cover.m_header.m_page= l_page;
-  strcpy((*io_layout).m_cover.m_header.m_tag, "Cover.Header");
+  g_strlcpy((*io_layout).m_cover.m_header.m_tag, "Cover.Header", sizeof((*io_layout).m_cover.m_header.m_tag));
   iwr_page_set_section_type(l_page, section_cover_header);
   iwr_page_set_paper(l_page, &l_paper);
   gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
@@ -75,7 +75,7 @@ layout_add_default_sections(
   gtk_widget_set_sensitive(l_widget, 0);
   l_page= IWR_PAGE(iwr_page_new());
   (*io_layout).m_report.m_header.m_page= l_page;
-  strcpy((*io_layout).m_report.m_header.m_tag, "Report.Header");
+  g_strlcpy((*io_layout).m_report.m_header.m_tag, "Report.Header", sizeof((*io_layout).m_report.m_header.m_tag));
   iwr_page_set_section_type(l_page, section_report_header);
   l_paper.m_height= POINTS_PER_INCH * 1.5;
   iwr_page_set_paper(l_page, &l_paper);
@@ -88,7 +88,7 @@ layout_add_default_sections(
   gtk_widget_set_sensitive(l_widget, 0);
   l_page= IWR_PAGE(iwr_page_new());
   (*io_layout).m_report.m_detail.m_page= l_page;
-  strcpy((*io_layout).m_report.m_detail.m_tag, "Report.Detail");
+  g_strlcpy((*io_layout).m_report.m_detail.m_tag, "Report.Detail", sizeof((*io_layout).m_report.m_detail.m_tag));
   iwr_page_set_section_type(l_page, section_report_detail);
   l_paper.m_height= POINTS_PER_INCH * 1.5;
   iwr_page_set_paper(l_page, &l_paper);
@@ -101,7 +101,7 @@ layout_add_default_sections(
   gtk_widget_set_sensitive(l_widget, 0);
   l_page= IWR_PAGE(iwr_page_new());
   (*io_layout).m_report.m_footer.m_page= l_page;
-  strcpy((*io_layout).m_report.m_footer.m_tag, "Report.Footer");
+  g_strlcpy((*io_layout).m_report.m_footer.m_tag, "Report.Footer", sizeof((*io_layout).m_report.m_footer.m_tag));
   iwr_page_set_section_type(l_page, section_report_footer);
   l_paper.m_height= POINTS_PER_INCH * 1.0;
   iwr_page_set_paper(l_page, &l_paper);
@@ -115,7 +115,7 @@ layout_add_default_sections(
   gtk_widget_set_sensitive(l_widget, 0);
   l_page= IWR_PAGE(iwr_page_new());
   (*io_layout).m_cover.m_footer.m_page= l_page;
-  strcpy((*io_layout).m_cover.m_footer.m_tag, "Cover.Footer");
+  g_strlcpy((*io_layout).m_cover.m_footer.m_tag, "Cover.Footer", sizeof((*io_layout).m_cover.m_footer.m_tag));
   iwr_page_set_section_type(l_page, section_cover_footer);
   l_paper.m_height= l_paper_height;
   iwr_page_set_paper(l_page, &l_paper);
@@ -128,165 +128,6 @@ layout_add_default_sections(
   return;
 }
 
-static void
-layout_divisions_read_config(
-  struct layout*const                   io_layout)
-{
-  struct paper                          l_paper;
-  IwrPage*                              l_page;
-  unsigned                              l_slot;
-
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
-
-  l_page= (*io_layout).m_cover.m_header.m_page;
-  if (l_page)
-  {
-    config_read_division_height(
-      &l_paper.m_height,
-      (*io_layout).m_cover.m_header.m_tag,
-      &(*io_layout).m_config);
-    iwr_page_set_paper(l_page, &l_paper);
-  }
-
-  l_page= (*io_layout).m_cover.m_footer.m_page;
-  if (l_page)
-  {
-    config_read_division_height(
-      &l_paper.m_height,
-      (*io_layout).m_cover.m_footer.m_tag,
-      &(*io_layout).m_config);
-    iwr_page_set_paper(l_page, &l_paper);
-  }
-
-  l_page= (*io_layout).m_report.m_header.m_page;
-  if (l_page)
-  {
-    config_read_division_height(
-      &l_paper.m_height,
-      (*io_layout).m_report.m_header.m_tag,
-      &(*io_layout).m_config);
-    iwr_page_set_paper(l_page, &l_paper);
-  }
-
-  l_page= (*io_layout).m_report.m_detail.m_page;
-  if (l_page)
-  {
-    config_read_division_height(
-      &l_paper.m_height,
-      (*io_layout).m_report.m_detail.m_tag,
-      &(*io_layout).m_config);
-    iwr_page_set_paper(l_page, &l_paper);
-  }
-
-  l_page= (*io_layout).m_report.m_footer.m_page;
-  if (l_page)
-  {
-    config_read_division_height(
-      &l_paper.m_height,
-      (*io_layout).m_report.m_footer.m_tag,
-      &(*io_layout).m_config);
-    iwr_page_set_paper(l_page, &l_paper);
-  }
-
-  for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
-  {
-    l_page= (*io_layout).m_group[l_slot].m_header.m_page;
-    config_read_division_height(
-      &l_paper.m_height,
-      (*io_layout).m_group[l_slot].m_header.m_tag,
-      &(*io_layout).m_config);
-    iwr_page_set_paper(l_page, &l_paper);
-
-    l_page= (*io_layout).m_group[l_slot].m_footer.m_page;
-    config_read_division_height(
-      &l_paper.m_height,
-      (*io_layout).m_group[l_slot].m_footer.m_tag,
-      &(*io_layout).m_config);
-    iwr_page_set_paper(l_page, &l_paper);
-  }
-
-  return;
-}
-
-static void
-layout_divisions_write_config(
-  struct layout const*const             i_layout)
-{
-  IwrPage*                              l_page;
-  struct paper                          l_paper;
-  unsigned                              l_slot;
-
-  l_page= (*i_layout).m_cover.m_header.m_page;
-  if (l_page)
-  {
-    iwr_page_get_paper(&l_paper, l_page);
-    config_write_division_height(
-      &(*i_layout).m_config,
-      (*i_layout).m_cover.m_header.m_tag,
-      l_paper.m_height);
-  }
-
-  l_page= (*i_layout).m_cover.m_footer.m_page;
-  if (l_page)
-  {
-    iwr_page_get_paper(&l_paper, l_page);
-    config_write_division_height(
-      &(*i_layout).m_config,
-      (*i_layout).m_cover.m_footer.m_tag,
-      l_paper.m_height);
-  }
-
-  l_page= (*i_layout).m_report.m_header.m_page;
-  if (l_page)
-  {
-    iwr_page_get_paper(&l_paper, l_page);
-    config_write_division_height(
-      &(*i_layout).m_config,
-      (*i_layout).m_report.m_header.m_tag,
-      l_paper.m_height);
-  }
-
-  l_page= (*i_layout).m_report.m_detail.m_page;
-  if (l_page)
-  {
-    iwr_page_get_paper(&l_paper, l_page);
-    config_write_division_height(
-      &(*i_layout).m_config,
-      (*i_layout).m_report.m_detail.m_tag,
-      l_paper.m_height);
-  }
-
-  l_page= (*i_layout).m_report.m_footer.m_page;
-  if (l_page)
-  {
-    iwr_page_get_paper(&l_paper, l_page);
-    config_write_division_height(
-      &(*i_layout).m_config,
-      (*i_layout).m_report.m_footer.m_tag,
-      l_paper.m_height);
-  }
-
-  for (l_slot= 0; (*i_layout).m_group_slots > l_slot; l_slot++)
-  {
-
-    l_page= (*i_layout).m_group[l_slot].m_header.m_page;
-    iwr_page_get_paper(&l_paper, l_page);
-    config_write_division_height(
-      &(*i_layout).m_config,
-      (*i_layout).m_group[l_slot].m_header.m_tag,
-      l_paper.m_height);
-
-    l_page= (*i_layout).m_group[l_slot].m_footer.m_page;
-    iwr_page_get_paper(&l_paper, l_page);
-    config_write_division_height(
-      &(*i_layout).m_config,
-      (*i_layout).m_group[l_slot].m_footer.m_tag,
-      l_paper.m_height);
-  }
-
-  return;
-}
-
 extern void
 layout_add_divisions_to_grid(
   struct layout*const                   io_layout)
@@ -406,23 +247,13 @@ layout_assign(
 {
 
   memset(o_layout, 0, sizeof(*o_layout));
-  config_assign(&(*o_layout).m_config);
+  paper_assign(&(*o_layout).m_paper);
+  paper_convert_to_points(&(*o_layout).m_paper);
   (*o_layout).m_scale= 1.0;
 
   return;
 }
 
-extern void
-layout_assign_filename(
-  struct layout*const                   io_layout,
-  char const*                           i_filename)
-{
-
-  config_assign_filename(&(*io_layout).m_config, i_filename);
-
-  return;
-}
-
 extern void
 layout_delete_coverfooter(
   struct layout*const                   io_layout)
@@ -639,7 +470,7 @@ layout_discharge(
 {
   unsigned                              l_slot;
 
-  config_discharge(&(*io_layout).m_config);
+  paper_discharge(&(*io_layout).m_paper);
 
   g_free((*io_layout).m_page_break.m_value);
 
@@ -774,6 +605,7 @@ layout_item_new(
   struct item_node*                     l_node;
   IwrPage*                              l_page;
 
+  l_node= 0;
   l_page= layout_get_focused_page(io_layout);
 
   do
@@ -912,12 +744,9 @@ layout_new_coverfooter(
   struct layout*const                   io_layout)
 {
   IwrPage*                              l_page;
-  struct paper                          l_paper;
   gint                                  l_row;
   GtkWidget*                            l_widget;
 
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
-
   do
   {
 
@@ -959,9 +788,9 @@ layout_new_coverfooter(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_cover.m_footer.m_page= l_page;
-    strcpy((*io_layout).m_cover.m_footer.m_tag, "Cover.Footer");
+    g_strlcpy((*io_layout).m_cover.m_footer.m_tag, "Cover.Footer", sizeof((*io_layout).m_cover.m_footer.m_tag));
     iwr_page_set_section_type(l_page, section_cover_footer);
-    iwr_page_set_paper(l_page, &l_paper);
+    iwr_page_set_paper(l_page, &(*io_layout).m_paper);
     gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
     gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, l_row++, 1, 1);
 
@@ -980,11 +809,8 @@ layout_new_coverheader(
   struct layout*const                   io_layout)
 {
   IwrPage*                              l_page;
-  struct paper                          l_paper;
   GtkWidget*                            l_widget;
 
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
-
   do
   {
 
@@ -998,9 +824,9 @@ layout_new_coverheader(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_cover.m_header.m_page= l_page;
-    strcpy((*io_layout).m_cover.m_header.m_tag, "Cover.Header");
+    g_strlcpy((*io_layout).m_cover.m_header.m_tag, "Cover.Header", sizeof((*io_layout).m_cover.m_header.m_tag));
     iwr_page_set_section_type(l_page, section_cover_header);
-    iwr_page_set_paper(l_page, &l_paper);
+    iwr_page_set_paper(l_page, &(*io_layout).m_paper);
     gtk_grid_insert_row((*io_layout).m_grid, 0);
     gtk_grid_attach((*io_layout).m_grid, l_widget, 0, 0, 1, 1);
     gtk_grid_insert_row((*io_layout).m_grid, 1);
@@ -1025,7 +851,7 @@ layout_new_reportdetail(
   gint                                  l_row;
   GtkWidget*                            l_widget;
 
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
+  l_paper= (*io_layout).m_paper;
 
   do
   {
@@ -1054,7 +880,7 @@ layout_new_reportdetail(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_report.m_detail.m_page= l_page;
-    strcpy((*io_layout).m_report.m_detail.m_tag, "Report.Detail");
+    g_strlcpy((*io_layout).m_report.m_detail.m_tag, "Report.Detail", sizeof((*io_layout).m_report.m_detail.m_tag));
     iwr_page_set_section_type(l_page, section_report_detail);
     l_paper.m_height= POINTS_PER_INCH * 1.5;
     iwr_page_set_paper(l_page, &l_paper);
@@ -1082,7 +908,7 @@ layout_new_reportfooter(
   gint                                  l_row;
   GtkWidget*                            l_widget;
 
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
+  l_paper= (*io_layout).m_paper;
 
   do
   {
@@ -1121,7 +947,7 @@ layout_new_reportfooter(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_report.m_footer.m_page= l_page;
-    strcpy((*io_layout).m_report.m_footer.m_tag, "Report.Footer");
+    g_strlcpy((*io_layout).m_report.m_footer.m_tag, "Report.Footer", sizeof((*io_layout).m_report.m_footer.m_tag));
     l_paper.m_height= POINTS_PER_INCH * 1.0;
     iwr_page_set_section_type(l_page, section_report_footer);
     iwr_page_set_paper(l_page, &l_paper);
@@ -1147,7 +973,7 @@ layout_new_reportheader(
   gint                                  l_row;
   GtkWidget*                            l_widget;
 
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
+  l_paper= (*io_layout).m_paper;
 
   do
   {
@@ -1170,7 +996,7 @@ layout_new_reportheader(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_report.m_header.m_page= l_page;
-    strcpy((*io_layout).m_report.m_header.m_tag, "Report.Header");
+    g_strlcpy((*io_layout).m_report.m_header.m_tag, "Report.Header", sizeof((*io_layout).m_report.m_header.m_tag));
     iwr_page_set_section_type(l_page, section_report_header);
     l_paper.m_height= POINTS_PER_INCH * 1.5;
     iwr_page_set_paper(l_page, &l_paper);
@@ -1198,7 +1024,7 @@ layout_paper_changed(
   struct paper                          l_paper2;
   unsigned                              l_slot;
 
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
+  l_paper= (*io_layout).m_paper;
 
   l_page= (*io_layout).m_cover.m_header.m_page;
   if (l_page)
@@ -1254,382 +1080,6 @@ layout_paper_changed(
   return;
 }
 
-static void
-layout_steal_division(
-  struct division*const                 io_target,
-  struct division*const                 io_source)
-{
-  struct item*                          l_target;
-  struct item*                          l_source;
-
-  do
-  {
-
-    if (0 == (*io_target).m_page)
-    {
-      strcpy((*io_target).m_tag, (*io_source).m_tag);
-      (*io_target).m_page= (*io_source).m_page;
-      break;
-    }
-
-    iwr_page_get_item(&l_target, (*io_target).m_page);
-    iwr_page_get_item(&l_source, (*io_source).m_page);
-
-    if (0 == (*l_target).m_head)
-    {
-      memcpy(l_target, l_source, sizeof(*l_target));
-    }
-    else
-    {
-      (*l_target).m_tail->m_next= (*l_source).m_head;
-      (*l_source).m_head->m_prev= (*l_target).m_tail; 
-      (*l_target).m_tail= (*l_source).m_tail;
-    }
-
-    memset(l_source, 0, sizeof(*l_source));
-    gtk_widget_destroy(GTK_WIDGET((*io_source).m_page));
-
-  }while(0);
-
-  memset(io_source, 0, sizeof(*io_source));
-
-  return;
-}
-
-static int
-layout_read_division(
-  GError**                              o_error,
-  struct layout *const                  io_layout,
-  struct bson_node const*const          i_bson_section)
-{
-  struct division                       l_division;
-  int                                   l_exit;
-  enum iwr_page_section_type            l_type;
-
-  memset(&l_division, 0, sizeof(l_division));
-
-  do
-  {
-
-    strncpy(
-      l_division.m_tag,
-      (*i_bson_section).m_ename,
-      sizeof(l_division.m_tag));
-
-    l_division.m_page= IWR_PAGE(iwr_page_new());
-
-    l_exit= iwr_page_read(
-      o_error,
-      l_division.m_page, 
-      (*i_bson_section).m_object.m_array.m_head);
-
-    if (l_exit)
-    {
-      gtk_widget_destroy(GTK_WIDGET(l_division.m_page));
-      break;
-    }
-
-    iwr_page_get_section_type(&l_type, l_division.m_page);
-
-    switch(l_type)
-    {
-    case section_cover_header:
-      layout_steal_division(&(*io_layout).m_cover.m_header, &l_division);
-      break;
-    case section_cover_footer:
-      layout_steal_division(&(*io_layout).m_cover.m_footer, &l_division);
-      break;
-    case section_report_header:
-      layout_steal_division(&(*io_layout).m_report.m_header, &l_division);
-      break;
-    case section_report_detail:
-      layout_steal_division(&(*io_layout).m_report.m_detail, &l_division);
-      break;
-    case section_report_footer:
-      layout_steal_division(&(*io_layout).m_report.m_footer, &l_division);
-      break;
-    default:
-      gtk_widget_destroy(GTK_WIDGET(l_division.m_page));
-      break;
-    }
-
-  }while(0);
-
-  return l_exit;
-}
-
-static int
-layout_read_divisions(
-  GError**                              o_error,
-  struct layout *const                  io_layout,
-  struct bson_node const*const          i_bson_document)
-{
-  int                                   l_exit;
-  struct bson_node const*               l_bson_section;
-
-  l_exit= 0;
-  l_bson_section= (*i_bson_document).m_object.m_document.m_head;
-
-  do
-  {
-
-    if (0 == l_bson_section)
-    {
-      break;
-    }
-
-    if (bson_type_array == (*l_bson_section).m_type)
-    {
-
-      l_exit= layout_read_division(o_error, io_layout, l_bson_section);
-
-      if (l_exit)
-      {
-        break;
-      }
-    }
-
-    l_bson_section= (*l_bson_section).m_next;
-
-  }while(1);
-
-  return l_exit;
-}
-
-static int
-layout_read_group(
-  GError**                              o_error,
-  struct layout *const                  io_layout,
-  struct bson_node const*const          i_bson_group)
-{
-  int                                   l_exit;
-  int                                   l_found;
-  struct division_group                 l_group;
-  struct bson_node*                     l_bson_header;
-  struct bson_node*                     l_bson_footer;
-  unsigned                              l_slot;
-  struct division_group*                l_ptr;
-
-  l_exit= 0;
-  memset(&l_group, 0, sizeof(l_group));
-  
-  do
-  {
-
-    strncpy(
-      l_group.m_break.m_tag,
-      (*i_bson_group).m_ename, 
-      sizeof(l_group.m_break.m_tag));
-
-    l_bson_header= (*i_bson_group).m_object.m_array.m_head;
-    l_group.m_header.m_page= IWR_PAGE(iwr_page_new());
-
-    strncpy(
-      l_group.m_header.m_tag, 
-      (*l_bson_header).m_ename,
-      sizeof(l_group.m_header.m_tag));
-
-    l_exit= iwr_page_read(
-      o_error,
-      l_group.m_header.m_page,
-      (*l_bson_header).m_object.m_array.m_head);
-
-    if (l_exit)
-    {
-      gtk_widget_destroy(GTK_WIDGET(l_group.m_header.m_page));
-      break;
-    }
-  
-    l_bson_footer= (*l_bson_header).m_next;
-    l_group.m_footer.m_page= IWR_PAGE(iwr_page_new());
-
-    strncpy(
-      l_group.m_footer.m_tag, 
-      (*l_bson_footer).m_ename,
-      sizeof(l_group.m_footer.m_tag));
-
-    l_exit= iwr_page_read(
-      o_error,
-      l_group.m_footer.m_page,
-      (*l_bson_footer).m_object.m_array.m_head);
-
-    if (l_exit)
-    {
-      gtk_widget_destroy(GTK_WIDGET(l_group.m_header.m_page));
-      gtk_widget_destroy(GTK_WIDGET(l_group.m_footer.m_page));
-      break;
-    }
-  
-    l_found= 0;
-    for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
-    {
-
-      l_found= (0 == strcmp(
-        (*io_layout).m_group[l_slot].m_break.m_tag,
-        l_group.m_break.m_tag));
-
-      if (l_found)
-      {
-        layout_steal_division(
-          &(*io_layout).m_group[l_slot].m_header,
-          &l_group.m_header);
-        layout_steal_division(
-          &(*io_layout).m_group[l_slot].m_footer,
-          &l_group.m_footer);
-        break;
-      }
-
-    }
-
-    if (l_found)
-    {
-      break;
-    }
-
-    (*io_layout).m_group= realloc(
-      (*io_layout).m_group,
-      (1 + (*io_layout).m_group_slots) * sizeof(struct division_group));
-
-    l_ptr= &(*io_layout).m_group[(*io_layout).m_group_slots];
-    memset(l_ptr, 0, sizeof(*l_ptr));
-    (*io_layout).m_group_slots++;
-
-    strcpy((*l_ptr).m_break.m_tag, l_group.m_break.m_tag);
-    layout_steal_division(&(*l_ptr).m_header, &l_group.m_header);
-    layout_steal_division(&(*l_ptr).m_footer, &l_group.m_footer);
-
-  }while(0);
-
-  return l_exit;
-}
-
-static int
-layout_read_groups(
-  GError**                              o_error,
-  struct layout *const                  io_layout,
-  struct bson_node const*const          i_bson_document)
-{
-  int                                   l_exit;
-  struct bson_node const*               l_bson_section;
-
-  l_bson_section= (*i_bson_document).m_object.m_document.m_head;
-
-  do
-  {
-
-    if (0 == l_bson_section)
-    {
-      break;
-    }
-
-    if (bson_type_array == (*l_bson_section).m_type)
-    {
-      l_exit= layout_read_group(o_error, io_layout, l_bson_section);
-    }
-    else if (bson_type_string == (*l_bson_section).m_type)
-    {
-      if (0 == strcmp("page_break", (*l_bson_section).m_ename))
-      {
-        strncpy(
-          (*io_layout).m_page_break.m_tag,
-          (*l_bson_section).m_object.m_string.m_text, 
-          sizeof((*io_layout).m_page_break.m_tag));
-      }
-    }
-
-    l_bson_section= (*l_bson_section).m_next;
-
-  }while(1);
-
-  return l_exit;
-}
-
-extern int
-layout_read(
-  GError**                              o_error,
-  struct layout *const                  io_layout,
-  struct bson_node const*const          i_element)
-{
-  struct bson_node const*               l_bson;
-  GError*                               l_error;
-  int                                   l_exit;
-  int                                   l_rc;
-
-  l_error= 0;
-
-  do
-  {
-
-    l_exit= config_read(&l_error, &(*io_layout).m_config);
-
-    if (l_exit)
-    {
-      break;
-    }
-
-    l_bson= i_element;
-
-    do
-    {
-
-      if (0 == l_bson)
-      {
-        break;
-      }
-
-      do
-      {
-
-        if (bson_type_document != (*l_bson).m_type)
-        {
-          break;
-        }
-
-        l_rc= strcmp("sections", (*l_bson).m_ename);
-
-        if (0 == l_rc) 
-        {
-          l_exit= layout_read_divisions(&l_error, io_layout, l_bson);
-          break;
-        }
-
-        l_rc= strcmp("groups", (*l_bson).m_ename);
-
-        if (0 == l_rc)
-        {
-          l_exit= layout_read_groups(&l_error, io_layout, l_bson);
-          break;
-        }
-
-      }while(0);
-
-      if (l_exit)
-      {
-        break;
-      }
-
-      l_bson= (*l_bson).m_next;
-
-    }while(1);
-
-    if (l_exit)
-    {
-      break;
-    }
-
-    layout_divisions_read_config(io_layout);
-    layout_add_divisions_to_grid(io_layout);
-
-  }while(0);
-
-  if (l_error)
-  {
-    g_propagate_error(o_error, l_error);
-  }
-
-  return l_exit;
-}
-
 extern void
 layout_set_horizontal_ruler_line(
   struct layout *const                  io_layout,
@@ -1747,11 +1197,9 @@ layout_set_layout_size(
     l_count++;
   }
 
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
-
   l_height*= (*io_layout).m_scale;
   l_height+= 32.0 * l_count;
-  l_width= (*io_layout).m_scale * l_paper.m_width;
+  l_width= (*io_layout).m_scale * (*io_layout).m_paper.m_width;
 
   gtk_layout_set_size((*io_layout).m_layout, l_width, l_height);
 
@@ -1953,15 +1401,16 @@ static int
 layout_write_division(
   GError**                              o_error,
   FILE*const                            io_fp,
-  struct division const*                i_division)
+  struct layout_division const*         i_division)
 {
+  GError*                               l_error;
   int                                   l_exit;
-  int32_t                               l_int32;
-  char                                  l_octet;
-  int32_t                               l_offset;
-  int32_t                               l_size;
+  struct item*                          l_item;
+  struct paper                          l_paper;
+  char const*                           l_text;
   enum iwr_page_section_type            l_type;
 
+  l_error= 0;
   l_exit= 0;
 
   do
@@ -1977,43 +1426,60 @@ layout_write_division(
       break;
     }
 
-    l_octet= bson_type_array;
-    fwrite(&l_octet, 1, 1, io_fp); 
-    fprintf(io_fp, "%s%c", (*i_division).m_tag, 0);
-
-    /* document */
-    l_offset= ftell(io_fp);
-    l_int32= 0;
-    fwrite(&l_int32, sizeof(int32_t), 1, io_fp); 
-
-    /* type */
     iwr_page_get_section_type(&l_type, (*i_division).m_page);
-    l_octet= bson_type_int32;
-    fwrite(&l_octet, 1, 1, io_fp); 
-    fprintf(io_fp, "type%c",0);
-    fwrite(&l_type, sizeof(int32_t), 1, io_fp);
 
-    l_exit= iwr_page_write(o_error, io_fp, (*i_division).m_page);
-
-    if (l_exit)
+    switch(l_type)
     {
-      break;
+      case section_cover_header:
+        l_text= "cover_header";
+        break;
+      case section_cover_footer:
+        l_text= "cover_footer";
+        break;
+      case section_report_header:
+        l_text= "report_header";
+        break;
+      case section_report_detail:
+        l_text= "report_detail";
+        break;
+      case section_report_footer:
+        l_text= "report_footer";
+        break;
+      case section_group_header:
+        l_text= "group_header";
+        break;
+      case section_group_footer:
+        l_text= "group_footer";
+        break;
+      default:
+        /* programming error */
+        l_text= "unkown";
+        break;
     }
 
-    /* end of document */
-    l_octet= 0;
-    fwrite(&l_octet, 1, 1, io_fp); 
+    fprintf(io_fp, "\t\t<section name=\"%s\" type=\"%s\">\n", 
+      (*i_division).m_tag,
+      l_text);
 
-    /* document */
-    l_int32= ftell(io_fp);
-    l_size= (l_int32 - l_offset);
-    fseek(io_fp, l_offset, SEEK_SET);
-    fwrite(&l_size, sizeof(l_size), 1, io_fp); 
+    iwr_page_get_paper(&l_paper, (*i_division).m_page); 
+    paper_convert_to_inches(&l_paper);
 
-    fseek(io_fp, 0, SEEK_END);
+    fprintf(io_fp, "\t\t\t<paper>\n");
+    fprintf(io_fp, "\t\t\t\t<height>%lf</height>\n", l_paper.m_height);
+    fprintf(io_fp, "\t\t\t</paper>\n");
+
+    iwr_page_get_item(&l_item, (*i_division).m_page);
+    l_exit= item_node_write(&l_error, io_fp, l_item);
+
+    fprintf(io_fp, "\t\t</section>\n");
 
   }while(0);
 
+  if (l_error)
+  {
+    g_propagate_error(o_error, l_error);
+  }
+
   return l_exit;
 }
 
@@ -2024,22 +1490,11 @@ layout_write_divisions(
   struct layout const*const             i_layout)
 {
   int                                   l_exit;
-  int32_t                               l_int32;
-  char                                  l_octet;
-  int32_t                               l_offset;
-  int32_t                               l_size;
 
   do
   {
 
-    l_octet= bson_type_document;
-    fwrite(&l_octet, 1, 1, io_fp); 
-    fprintf(io_fp, "%s%c", "sections", 0);
-
-    /* document */
-    l_offset= ftell(io_fp);
-    l_int32= 0;
-    fwrite(&l_int32, sizeof(int32_t), 1, io_fp); 
+    fprintf(io_fp, "\t<division>\n");
 
     l_exit= layout_write_division(o_error, io_fp, &(*i_layout).m_cover.m_header);
 
@@ -2076,47 +1531,28 @@ layout_write_divisions(
       break;
     }
 
-    /* end of document */
-    l_octet= 0;
-    fwrite(&l_octet, 1, 1, io_fp); 
-
-    /* document */
-    l_int32= ftell(io_fp);
-    l_size= (l_int32 - l_offset);
-    fseek(io_fp, l_offset, SEEK_SET);
-    fwrite(&l_size, sizeof(l_size), 1, io_fp); 
-
-    fseek(io_fp, 0, SEEK_END);
+    fprintf(io_fp, "\t</division>\n");
 
   }while(0);
 
   return l_exit;
 }
 
-extern int
+static int
 layout_write_group(
   GError**                              o_error,
   FILE*const                            io_fp,
-  struct division_group const*const     i_group)
+  struct layout_division_group const*const i_group)
 {
   int                                   l_exit;
-  int32_t                               l_int32;
-  char                                  l_octet;
-  int32_t                               l_offset;
-  int32_t                               l_size;
+
+  l_exit= 0;
 
   do
   {
 
-    l_octet= bson_type_array;
-    fwrite(&l_octet, 1, 1, io_fp); 
-    fprintf(io_fp, "%s%c", (*i_group).m_break.m_tag, 0);
-
-    /* document */
-    l_offset= ftell(io_fp);
-    l_int32= 0;
-    fwrite(&l_int32, sizeof(int32_t), 1, io_fp); 
-
+    fprintf(io_fp, "\t\t<group name=\"%s\">\n", (*i_group).m_break.m_tag);
+    
     l_exit= layout_write_division(o_error, io_fp, &(*i_group).m_header);
 
     if (l_exit)
@@ -2131,17 +1567,7 @@ layout_write_group(
       break;
     }
 
-    /* end of document */
-    l_octet= 0;
-    fwrite(&l_octet, 1, 1, io_fp); 
-
-    /* document */
-    l_int32= ftell(io_fp);
-    l_size= (l_int32 - l_offset);
-    fseek(io_fp, l_offset, SEEK_SET);
-    fwrite(&l_size, sizeof(l_size), 1, io_fp); 
-
-    fseek(io_fp, 0, SEEK_END);
+    fprintf(io_fp, "\t\t</group>\n");
 
   }while(0);
 
@@ -2155,40 +1581,20 @@ layout_write_groups(
   struct layout const*const             i_layout)
 {
   int                                   l_exit;
-  struct division_group*                l_group;
-  int32_t                               l_int32;
-  char                                  l_octet;
-  int32_t                               l_offset;
-  int32_t                               l_size;
+  struct layout_division_group*         l_group;
   unsigned                              l_slot;
 
+  l_exit= 0;
+
   do
   {
 
-    if ((0 == (*i_layout).m_group_slots) &&
-      (0 == (*i_layout).m_page_break.m_tag[0]))
-    {
-      break;
-    } 
+    fprintf(io_fp, "\t<groups>\n");
 
-    l_octet= bson_type_document;
-    fwrite(&l_octet, 1, 1, io_fp); 
-    fprintf(io_fp, "%s%c", "groups", 0);
-
-    /* document */
-    l_offset= ftell(io_fp);
-    l_int32= 0;
-    fwrite(&l_int32, sizeof(int32_t), 1, io_fp); 
-
-    /* page break */
     if ((*i_layout).m_page_break.m_tag[0])
     {
-      l_octet= bson_type_string;
-      fwrite(&l_octet, 1, 1, io_fp); 
-      fprintf(io_fp, "page_break%c",0);
-      l_int32= 1+strlen((*i_layout).m_page_break.m_tag);
-      fwrite(&l_int32, sizeof(int32_t), 1, io_fp); 
-      fwrite((*i_layout).m_page_break.m_tag, 1, l_int32, io_fp);
+      fprintf(io_fp, "\t\t<page_break>%s</page_break>\n",
+        (*i_layout).m_page_break.m_tag);
     }
 
     l_group= &(*i_layout).m_group[0];
@@ -2206,17 +1612,7 @@ layout_write_groups(
       l_group++;
     }
 
-    /* end of document */
-    l_octet= 0;
-    fwrite(&l_octet, 1, 1, io_fp); 
-
-    /* document */
-    l_int32= ftell(io_fp);
-    l_size= (l_int32 - l_offset);
-    fseek(io_fp, l_offset, SEEK_SET);
-    fwrite(&l_size, sizeof(l_size), 1, io_fp); 
-
-    fseek(io_fp, 0, SEEK_END);
+    fprintf(io_fp, "\t</groups>\n");
 
   }while(0);
 
@@ -2230,19 +1626,20 @@ layout_write(
   struct layout const*const             i_layout)
 {
   int                                   l_exit;
+  struct paper                          l_paper;
 
   do
   {
 
-    l_exit= config_write(o_error, &(*i_layout).m_config);
+    l_paper= (*i_layout).m_paper;
+    paper_convert_to_inches(&l_paper);
+    l_exit= paper_write(o_error, io_fp, &l_paper);
 
     if (l_exit)
     {
       break;
     }
 
-    layout_divisions_write_config(i_layout);
-
     l_exit= layout_write_divisions(o_error, io_fp, i_layout);
 
     if (l_exit)
