@@ -42,7 +42,7 @@ struct break_dialog
 struct break_group
 {
   int                                   m_has_ref; 
-  struct division_group                 m_division;
+  struct layout_division_group          m_division;
 };
 
 static void
@@ -273,11 +273,11 @@ break_groups_remove(
   gint                                  l_bottom_row;
   gboolean                              l_found;
   gint                                  l_group_slot;
-  struct division_group*                l_head;
+  struct layout_division_group*         l_head;
   gint                                  l_offset;
   gint                                  l_row;
   gint                                  l_slot;
-  struct division_group*                l_tail;
+  struct layout_division_group*         l_tail;
   gint                                  l_top_row;
 
   l_row= 0;
@@ -331,17 +331,16 @@ break_groups_remove(
     }
 
     l_bottom_row+= l_row + l_offset;
-/*
+
     gtk_grid_remove_row((*io_layout).m_grid, l_bottom_row);
     gtk_grid_remove_row((*io_layout).m_grid, l_bottom_row);
-*/
+
 
     l_top_row= (2*l_group_slot);
     l_top_row+= l_row;
-/*
+
     gtk_grid_remove_row((*io_layout).m_grid, l_top_row);
     gtk_grid_remove_row((*io_layout).m_grid, l_top_row);
-*/
 
     if (1 < (*io_layout).m_group_slots)
     {
@@ -357,7 +356,7 @@ break_groups_remove(
 
       (*io_layout).m_group= realloc(
         (*io_layout).m_group,
-        (*io_layout).m_group_slots * sizeof(struct division_group));
+        (*io_layout).m_group_slots * sizeof(struct layout_division_group));
     }
     else
     {
@@ -380,14 +379,14 @@ break_group_new(
 {
   struct break_group*                   l_break;
   gboolean                              l_found;
-  struct division_group*                l_group;
+  struct layout_division_group*         l_group;
   unsigned                              l_index;
   struct paper                          l_paper;
   unsigned                              l_slot;
 
   l_break= (struct break_group*)g_malloc0(i_list_slots * sizeof(*l_break));
 
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
+  l_paper= (*io_layout).m_paper;
   l_paper.m_height= POINTS_PER_INCH * 1.0;
 
   for (l_slot= 0; i_list_slots > l_slot; l_slot++)
@@ -465,10 +464,8 @@ break_remove_all_groups(
 
   for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
   {
-/*
     gtk_grid_remove_row((*io_layout).m_grid, l_row);
     gtk_grid_remove_row((*io_layout).m_grid, l_row);
-*/
   }
 
   l_row= 0;
@@ -487,10 +484,8 @@ break_remove_all_groups(
 
   for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
   {
-/*
     gtk_grid_remove_row((*io_layout).m_grid, l_row);
     gtk_grid_remove_row((*io_layout).m_grid, l_row);
-*/
   }
 
   g_free((*io_layout).m_group);
@@ -580,7 +575,7 @@ break_groups_add(
     gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_break[l_slot].m_division.m_header.m_page), 0, l_row++, 1, 1);
   }
 
-  (*io_layout).m_group= (struct division_group*)g_malloc0(i_list_slots * sizeof(struct division_group));
+  (*io_layout).m_group= (struct layout_division_group*)g_malloc0(i_list_slots * sizeof(struct layout_division_group));
   (*io_layout).m_group_slots= i_list_slots;
 
   for (l_slot= 0; i_list_slots > l_slot; l_slot++)
@@ -767,7 +762,7 @@ layout_break_property(
     break_property_create_model_view(&l_bd);
     break_property_set_values(&l_bd, io_layout);
 
-    gtk_window_set_transient_for(GTK_WINDOW(l_dialog), mainw());
+    gtk_window_set_transient_for(GTK_WINDOW(l_dialog), get_main_window());
     gtk_widget_show_all(GTK_WIDGET(l_dialog));
     gtk_window_set_modal(GTK_WINDOW(l_dialog), 1);
 
