@@ -2,7 +2,7 @@
 vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler 
 */
 /*
-Copyright (c) 2015, iwrite authors 
+Copyright (c) 2015-2016, iwrite authors 
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -38,16 +38,10 @@ about_menuitem_activate_cb(
   GtkDialog*                            l_dialog;
   char const*                           l_stage;
 
-  switch(g_version.m_stage)
-  {
-    case stage_alpha: l_stage= "alpha"; break;
-    case stage_beta: l_stage= "beta"; break;
-    case stage_candidate: l_stage= "candidate"; break;
-    case stage_released: l_stage= "released"; break;
-  }
+  l_stage= version_get_stage_text(g_version.m_stage);
 
   l_dialog= GTK_DIALOG(gtk_message_dialog_new(
-    mainw(),
+    get_main_window(),
     GTK_DIALOG_MODAL,
     GTK_MESSAGE_INFO,
     GTK_BUTTONS_OK,
@@ -412,7 +406,7 @@ open_menuitem_activate_cb(
     l_dialog = gtk_file_chooser_dialog_new(
       "Open Report",
       (*l_mainw).m_window,
-      GTK_FILE_CHOOSER_ACTION_SAVE,
+      GTK_FILE_CHOOSER_ACTION_OPEN,
       "_Cancel",
       GTK_RESPONSE_CANCEL,
       "_Save",
@@ -421,18 +415,9 @@ open_menuitem_activate_cb(
 
     l_chooser= GTK_FILE_CHOOSER(l_dialog);
     
-    if ((*l_mainw).m_report.m_reportfile)
-    {
-      gtk_file_chooser_set_filename(l_chooser, (*l_mainw).m_report.m_reportfile);
-    }
-    else
-    {
-      gtk_file_chooser_set_current_name(l_chooser, "Untitled");
-    }
-
     l_filter= gtk_file_filter_new();
-    gtk_file_filter_add_pattern(l_filter, "*.bson");
-    gtk_file_filter_set_name(l_filter, "BSON");
+    gtk_file_filter_add_pattern(l_filter, "*.irpt");
+    gtk_file_filter_set_name(l_filter, "iwrite report");
     gtk_file_chooser_add_filter(l_chooser, l_filter);
 
     l_rc= gtk_dialog_run(GTK_DIALOG(l_dialog));
@@ -495,8 +480,8 @@ pagesetup_menuitem_activate_cb(
 
     if (style_layout == (*l_mainw).m_report.m_style)
     {
-      l_exit= page_setup_property(
-        &(*l_mainw).m_report.m_object.m_layout.m_config.m_page_setup);
+      l_exit= layout_page_setup_property(
+        &(*l_mainw).m_report.m_object.m_layout.m_paper);
 
       if (0 == l_exit)
       {
@@ -508,7 +493,7 @@ pagesetup_menuitem_activate_cb(
     else if (style_label == (*l_mainw).m_report.m_style)
     {
       l_exit= label_page_setup_property(
-        &(*l_mainw).m_report.m_object.m_label.m_config.m_paper);
+        &(*l_mainw).m_report.m_object.m_label.m_paper);
 
       if (0 == l_exit)
       {
