@@ -306,7 +306,7 @@ query_exec_prompt_resolve(
 
   l_dialog= GTK_DIALOG(gtk_dialog_new_with_buttons(
     "SQL query input",
-    mainw(),
+    get_main_window(),
     GTK_DIALOG_MODAL,
     "Ok",
     GTK_RESPONSE_OK,
