@@ -240,7 +240,7 @@ query_property_save(
   }
   else
   {
-    strcpy((*l_node).m_tag, "default");
+    g_strlcpy((*l_node).m_tag, "default", sizeof((*l_node).m_tag));
   }
 
   l_buffer= gtk_text_view_get_buffer((*io_qd).m_query_textview);
@@ -476,7 +476,7 @@ query_property_new(
     if (0 == l_node)
     {
       query_last_new(&l_node, (*io_qd).m_query);
-      sprintf((*l_node).m_tag, "default%ld", l_cur_value);
+      snprintf((*l_node).m_tag, sizeof((*l_node).m_tag), "default%ld", l_cur_value);
 
       (*io_qd).m_active= l_node;
 
@@ -617,6 +617,7 @@ query_property_show_results(
   GtkTextView*                          l_textview;
   char                                  l_buf[15+1];
 
+  l_builder= 0;
   l_dialog= 0;
   l_error= 0;
   l_text= 0;
@@ -716,7 +717,7 @@ query_property_show_results(
     l_buffer= gtk_text_view_get_buffer(l_textview);
     gtk_text_buffer_set_text(l_buffer, l_text, l_size);
 
-    gtk_window_set_transient_for(GTK_WINDOW(l_dialog), mainw());
+    gtk_window_set_transient_for(GTK_WINDOW(l_dialog), get_main_window());
     gtk_widget_show_all(GTK_WIDGET(l_dialog));
     gtk_window_set_modal(GTK_WINDOW(l_dialog), 1);
     gtk_dialog_run(l_dialog);
@@ -842,7 +843,7 @@ query_property(
       break;
     }
 
-    gtk_window_set_transient_for(GTK_WINDOW(l_dialog), mainw());
+    gtk_window_set_transient_for(GTK_WINDOW(l_dialog), get_main_window());
 
     l_qd.m_query= io_query;
     l_node= (*io_query).m_head;
@@ -853,7 +854,7 @@ query_property(
       if (0 == l_node)
       {
         query_first_new(&l_node, io_query);
-        strcpy((*l_node).m_tag, "primary");
+        g_strlcpy((*l_node).m_tag, "primary", sizeof((*l_node).m_tag));
         l_qd.m_active= l_node;
         break;
       }
