@@ -143,29 +143,6 @@ rw_discharge(
   return;
 }
 
-extern void
-rw_layout_clear_accumulator(
-  struct layout*const                   io_layout)
-{
-  unsigned                              l_slot;
-
-  rw_page_clear_accumulator((*io_layout).m_cover.m_header.m_page);
-  rw_page_clear_accumulator((*io_layout).m_cover.m_footer.m_page);
-  rw_page_clear_accumulator((*io_layout).m_report.m_header.m_page);
-  rw_page_clear_accumulator((*io_layout).m_report.m_detail.m_page);
-  rw_page_clear_accumulator((*io_layout).m_report.m_footer.m_page);
-
-  for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
-  {
-    g_free((*io_layout).m_group[l_slot].m_break.m_value);
-    (*io_layout).m_group[l_slot].m_break.m_value= 0;
-    rw_page_clear_accumulator((*io_layout).m_group[l_slot].m_header.m_page);
-    rw_page_clear_accumulator((*io_layout).m_group[l_slot].m_footer.m_page);
-  }
-
-  return;
-}
-
 static void
 rw_fbarcode_set_value(
   struct item_fbarcode*                 io_fbarcode,
@@ -188,7 +165,7 @@ rw_fbarcode_set_value(
     }
 
     memset(l_buf, 0, sizeof(l_buf));
-    strcpy(l_buf, (*io_fbarcode).m_tag);
+    g_strlcpy(l_buf, (*io_fbarcode).m_tag, sizeof(l_buf));
     l_ptr= strchr(l_buf, '.');
 
     if (0 == l_ptr)
@@ -237,7 +214,7 @@ rw_sum_set_value(
   {
 
     memset(l_buf, 0, sizeof(l_buf));
-    strcpy(l_buf, (*io_sum).m_tag);
+    g_strlcpy(l_buf, (*io_sum).m_tag, sizeof(l_buf));
     l_ptr= strchr(l_buf, '.');
 
     if (0 == l_ptr)
@@ -293,7 +270,7 @@ rw_fimage_set_value(
     }
 
     memset(l_buf, 0, sizeof(l_buf));
-    strcpy(l_buf, (*io_fimage).m_tag);
+    g_strlcpy(l_buf, (*io_fimage).m_tag, sizeof(l_buf));
     l_ptr= strchr(l_buf, '.');
 
     if (0 == l_ptr)
@@ -345,7 +322,7 @@ rw_fnumber_set_value(
     }
 
     memset(l_buf, 0, sizeof(l_buf));
-    strcpy(l_buf, (*io_fnumber).m_tag);
+    g_strlcpy(l_buf, (*io_fnumber).m_tag, sizeof(l_buf));
     l_ptr= strchr(l_buf, '.');
 
     if (0 == l_ptr)
@@ -395,7 +372,7 @@ rw_ftext_set_value(
     }
 
     memset(l_buf, 0, sizeof(l_buf));
-    strcpy(l_buf, (*io_ftext).m_tag);
+    g_strlcpy(l_buf, (*io_ftext).m_tag, sizeof(l_buf));
     l_ptr= strchr(l_buf, '.');
 
     if (0 == l_ptr)
@@ -424,68 +401,6 @@ rw_ftext_set_value(
   return;
 }
 
-extern void
-rw_level_break_set_value(
-  struct layout*const                   io_layout,
-  struct rw *const                      i_rw)
-{
-  struct iwsql_attr const*              l_attr;
-  struct division_group*                l_group;
-  unsigned                              l_slot;
-
-  l_attr= 0;
-
-  if ((*io_layout).m_page_break.m_value)
-  {
-    g_free((*io_layout).m_page_break.m_value);
-    (*io_layout).m_page_break.m_value= 0;
-  }
-
-  if ((*io_layout).m_page_break.m_tag && (*io_layout).m_page_break.m_tag[0])
-  {
-    rw_attr_lookup_by_name(
-      &l_attr,
-      &(*i_rw).m_exec,
-      "primary",
-      (*io_layout).m_page_break.m_tag);
-
-    if (l_attr)
-    {
-      (*io_layout).m_page_break.m_value= g_strdup((*l_attr).m_value);
-    }
-  }
-
-  for(
-    l_group= &(*io_layout).m_group[0], 
-    l_slot= 0; 
-    (*io_layout).m_group_slots > l_slot; 
-    l_slot++,
-    l_group++)
-  {
-
-    l_attr= 0;
-    rw_attr_lookup_by_name(
-      &l_attr,
-      &(*i_rw).m_exec,
-      "primary",
-      (*l_group).m_break.m_tag);
-
-    if ((*l_group).m_break.m_value)
-    {
-      g_free((*l_group).m_break.m_value);
-      (*l_group).m_break.m_value= 0;
-    }
-
-    if (l_attr)
-    {
-      (*l_group).m_break.m_value= g_strdup((*l_attr).m_value);
-    }
-
-  }
-
-  return;
-}
-
 /*
  * ':{'[table'.']field'}'
  * escape '::{' results in ':{'
@@ -650,69 +565,20 @@ rw_page_number_set_value(
 }
 
 extern void
-rw_layout_group_set_value(
-  struct layout*const                   io_layout,
-  struct rw*const                       io_rw)
+rw_item_clear_accumulator(
+  struct item*const                     io_item)
 {
-  unsigned                              l_slot;
-  struct division_group*                l_group;
-
-  l_group= &(*io_layout).m_group[0];
-
-  for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
-  {
-    rw_page_set_value((*l_group).m_header.m_page, io_rw);
-    rw_page_set_value((*l_group).m_footer.m_page, io_rw);
-    l_group++;
-  }
-
-  return;
-}
-
-extern void
-rw_layout_set_fence(
-  struct rw*const                       io_rw,
-  struct layout*const                   io_layout)
-{
-  struct paper                           l_paper;
-  struct paper                           l_paper2;
-
-  paper_set_from_page_setup_pt(&l_paper, (*io_layout).m_config.m_page_setup);
-  (*io_rw).m_fence_bottom= (l_paper.m_height - l_paper.m_margin_bottom);
-
-  do
-  {
-
-    if (0 == (*io_layout).m_report.m_footer.m_page)
-    {
-      break;
-    }
-
-    iwr_page_get_paper(&l_paper2, (*io_layout).m_report.m_footer.m_page);
-    (*io_rw).m_fence_bottom= l_paper.m_height - l_paper2.m_height;
-
-  }while(0);
-
-  return;
-}
-
-extern void
-rw_page_clear_accumulator(
-  IwrPage*const                         io_page)
-{
-  struct item*                          l_item;
   struct item_node*                     l_node;
 
   do
   {
 
-    if (0 == io_page)
+    if (0 == io_item || 0 == (*io_item).m_head)
     {
       break;
     }
 
-    iwr_page_get_item(&l_item, io_page);
-    l_node= (*l_item).m_head;
+    l_node= (*io_item).m_head;
 
     do
     {
@@ -747,23 +613,21 @@ rw_page_clear_accumulator(
 }
 
 extern void
-rw_page_set_value(
-  IwrPage*const                         io_page,
+rw_item_set_value(
+  struct item*const                     io_item,
   struct rw*const                       io_rw)
 {
-  struct item*                          l_item;
   struct item_node*                     l_node;
 
   do
   {
 
-    if (0 == io_page)
+    if (0 == io_item || 0 == (*io_item).m_head)
     {
       break;
     }
 
-    iwr_page_get_item(&l_item, io_page);
-    l_node= (*l_item).m_head;
+    l_node= (*io_item).m_head;
 
     do
     {
@@ -812,3 +676,136 @@ rw_page_set_value(
   return;
 }
 
+extern void
+rw_layout_clear_accumulator(
+  struct layout_spec*const              io_layout)
+{
+  unsigned                              l_slot;
+
+  rw_item_clear_accumulator((*io_layout).m_cover.m_header.m_item);
+  rw_item_clear_accumulator((*io_layout).m_cover.m_footer.m_item);
+  rw_item_clear_accumulator((*io_layout).m_report.m_header.m_item);
+  rw_item_clear_accumulator((*io_layout).m_report.m_detail.m_item);
+  rw_item_clear_accumulator((*io_layout).m_report.m_footer.m_item);
+
+  for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
+  {
+    g_free((*io_layout).m_group[l_slot].m_break.m_value);
+    (*io_layout).m_group[l_slot].m_break.m_value= 0;
+    rw_item_clear_accumulator((*io_layout).m_group[l_slot].m_header.m_item);
+    rw_item_clear_accumulator((*io_layout).m_group[l_slot].m_footer.m_item);
+  }
+
+  return;
+}
+
+extern void
+rw_level_break_set_value(
+  struct layout_spec*const              io_layout,
+  struct rw *const                      i_rw)
+{
+  struct iwsql_attr const*              l_attr;
+  struct layout_spec_division_group*    l_group;
+  unsigned                              l_slot;
+
+  l_attr= 0;
+
+  if ((*io_layout).m_page_break.m_value)
+  {
+    g_free((*io_layout).m_page_break.m_value);
+    (*io_layout).m_page_break.m_value= 0;
+  }
+
+  if ((*io_layout).m_page_break.m_tag && (*io_layout).m_page_break.m_tag[0])
+  {
+    rw_attr_lookup_by_name(
+      &l_attr,
+      &(*i_rw).m_exec,
+      "primary",
+      (*io_layout).m_page_break.m_tag);
+
+    if (l_attr)
+    {
+      (*io_layout).m_page_break.m_value= g_strdup((*l_attr).m_value);
+    }
+  }
+
+  for(
+    l_group= &(*io_layout).m_group[0], 
+    l_slot= 0; 
+    (*io_layout).m_group_slots > l_slot; 
+    l_slot++,
+    l_group++)
+  {
+
+    l_attr= 0;
+    rw_attr_lookup_by_name(
+      &l_attr,
+      &(*i_rw).m_exec,
+      "primary",
+      (*l_group).m_break.m_tag);
+
+    if ((*l_group).m_break.m_value)
+    {
+      g_free((*l_group).m_break.m_value);
+      (*l_group).m_break.m_value= 0;
+    }
+
+    if (l_attr)
+    {
+      (*l_group).m_break.m_value= g_strdup((*l_attr).m_value);
+    }
+
+  }
+
+  return;
+}
+
+
+extern void
+rw_layout_group_set_value(
+  struct layout_spec*const              io_layout,
+  struct rw*const                       io_rw)
+{
+  unsigned                              l_slot;
+  struct layout_spec_division_group*    l_group;
+
+  l_group= &(*io_layout).m_group[0];
+
+  for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
+  {
+    rw_item_set_value((*l_group).m_header.m_item, io_rw);
+    rw_item_set_value((*l_group).m_footer.m_item, io_rw);
+    l_group++;
+  }
+
+  return;
+}
+
+extern void
+rw_layout_set_fence(
+  struct rw*const                       io_rw,
+  struct layout_spec*const              io_layout)
+{
+
+  (*io_rw).m_fence_bottom= 
+    ((*io_layout).m_paper.m_height - (*io_layout).m_paper.m_margin_bottom);
+
+  do
+  {
+    if (0 == (*io_layout).m_report.m_footer.m_item ||
+      0 == (*io_layout).m_report.m_footer.m_item->m_head)
+    {
+      break;
+    }
+
+    (*io_rw).m_fence_bottom= 
+      (*io_layout).m_paper.m_height - 
+      (*io_layout).m_report.m_footer.m_paper.m_height;
+
+  }while(0);
+
+  return;
+}
+
+
