@@ -185,7 +185,6 @@ int rss14(struct zint_symbol *symbol, unsigned char source[], int src_len)
 			symbol->row_height[separator_row] = 1;
 			symbol->rows += 1;
 			break;
-		default: break;
 	}
 	
 	for(i = 0; i < 112; i++) {
@@ -2083,7 +2082,7 @@ int rssexpanded(struct zint_symbol *symbol, unsigned char source[], int src_len)
 		 * [01]90614141999996[10]1234222222222221
 		 * Patch by Daniel Frede
 		 */
-		codeblocks = (data_chars + 1) / 2 + 1;
+		codeblocks = (data_chars + 1) / 2 + ((data_chars + 1) % 2);
 		
 		if((symbol->option_2 < 1) || (symbol->option_2 > 10)) {
 			symbol->option_2 = 2;
@@ -2122,8 +2121,10 @@ int rssexpanded(struct zint_symbol *symbol, unsigned char source[], int src_len)
 					left_to_right = 1;
 					i = 2 + (current_block * 21);
 					for(j = 0; j < 21; j++) {
-						sub_elements[j + (reader * 21) + 2] = elements[i + j];
-						elements_in_sub++;
+                                                if((i + j) < pattern_width) {
+                                                        sub_elements[j + (reader * 21) + 2] = elements[i + j];
+                                                        elements_in_sub++;
+                                                }
 					}
 				} else {
 					/* right to left */
@@ -2132,8 +2133,10 @@ int rssexpanded(struct zint_symbol *symbol, unsigned char source[], int src_len)
 						/* a full row */
 						i = 2 + (((current_row * symbol->option_2) - reader - 1) * 21);
 						for(j = 0; j < 21; j++) {
-							sub_elements[(20 - j) + (reader * 21) + 2] = elements[i + j];
-							elements_in_sub++;
+                                                        if((i + j) < pattern_width) {
+                                                                sub_elements[(20 - j) + (reader * 21) + 2] = elements[i + j];
+                                                                elements_in_sub++;
+                                                        }
 						}
 					} else {
 						/* a partial row */
@@ -2141,8 +2144,10 @@ int rssexpanded(struct zint_symbol *symbol, unsigned char source[], int src_len)
 						l = (current_row * symbol->option_2) - reader - 1;
 						i = 2 + ((l - k) * 21);
 						for(j = 0; j < 21; j++) {
-							sub_elements[(20 - j) + (reader * 21) + 2] = elements[i + j];
-							elements_in_sub++;
+                                                        if((i + j) < pattern_width) {
+                                                                sub_elements[(20 - j) + (reader * 21) + 2] = elements[i + j];
+                                                                elements_in_sub++;
+                                                        }
 						}
 					}
 				}
